Coverage for /Users/rik/github/cgse/libs/cgse-common/src/egse/exceptions.py: 100%

1 class CGSEException(Exception):

2 """The base exception for all errors and warnings in the Common-EGSE."""

3

4 pass

5

6

7 class Error(CGSEException):

8 """The base class for all Common-EGSE Errors."""

9

10 pass

11

12

13 class Warning(CGSEException):

14 """The base class for all Common-EGSE Warnings."""

15

16 pass

17

18

19 class FileIsEmptyError(Error):

20 """Raised when a file is empty and that is unexpected."""

21

22 pass

23

24

25 class InvalidOperationError(Error):

26 """

27 Raised when a certain operation is not valid in the given state,

28 circumstances or environment.

29 """

30

31 pass

32

33

34 class InvalidInputError(Error):

35 """Exception raised when the input is invalid after editing."""

36

37 pass

38

39

40 class DeviceNotFoundError(Error):

41 """Raised when a device could not be located, or loaded."""

42

43 pass

44

45

46 class InternalStateError(Error):

47 """Raised when an object encounters an internal state inconsistency."""

48

49 pass

50

51

52 class InternalError(Error):

53 """Raised when an internal inconsistency occurred in a function, method or class."""

54

55 pass

56

57

58 class Abort(RuntimeError):

59 """Internal Exception to signal a process to abort."""

60

61

62 class InitialisationError(Error):

63 """Raised when an initialisation failed."""